check_genderdata_package: Check whether to install data for gender function and install...

Description Usage

View source: R/install-genderdata-package.R

Description

If the genderdata package is not installed, install it from GitHub using devtools. If it is not up to date, reinstall it.

Usage

1

lmullen/gender documentation built on Dec. 21, 2021, 11:44 a.m.